@@ -1,4 +1,4 @@
-from ocp_resources.resource import Resource
+from ocp_resources.resource import MissingRequiredArgumentError, Resource
 
 
 class ImageDigestMirrorSet(Resource):
@@ -23,9 +23,9 @@ class ImageDigestMirrorSet(Resource):
         self.image_digest_mirrors = image_digest_mirrors
         super().__init__(**kwargs)
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.image_digest_mirrors:
-                raise ValueError("image_digest_mirrors or yaml file must be defined")
+                raise MissingRequiredArgumentError(argument="image_digest_mirrors")
             self.res["spec"] = {"imageDigestMirrors": self.image_digest_mirrors}
